==> videopop_plus-0.5.5.zip: videopop_plus/videopop_link.php <==
<?php
/*
VideoPop+ Plugin - Get Video Object
Version: 0.5.5

 Released under the GPL license
  http://www.gnu.org/copyleft/gpl.html
*/

function getVideoPopObject($vid='',$cap_flg=true,$flvplayer='flvplayer.swf',$lynk_err_note='Sorry, video not available.',$video_sizes='') {
 $upload_dir    = 'wp-content/videopop/';
 $plugin_dir    = 'wp-content/plugins/videopop_plus/';
 $video_data    = 'videopopdata.txt';

 if (!is_array($video_sizes)) {
  $video_sizes = array(
             160 => array('width' => 160, 'height' => 120)
            ,320 => array('width' => 320, 'height' => 240)
            ,640 => array('width' => 640, 'height' => 480)
            ,450 => array('width' => 450, 'height' => 252)
            ,480 => array('width' => 480, 'height' => 260)
            ,719 => array('width' => 720, 'height' => 540)
            ,720 => array('width' => 720, 'height' => 405)
            ,721 => array('width' => 720, 'height' => 390)
            );
 }

 $video_tmpl  = array(
             'real' => "<object id=\"realplayer\" classid=\"clsid:cfcdaa03-8be4-11cf-b84b-0020afbbccfa\" width=\"%1\$s\" height=\"%2\$s\"><param name=\"src\" value=\"%3\$s\" /><param name=\"autostart\" value=\"true\" /><param name=\"controls\" value=\"imagewindow,controlpanel\" /><embed src=\"%3\$s\" width=\"%1\$s\" height=\"%2\$s\" autostart=\"true\" controls=\"imagewindow,controlpanel\" type=\"audio/x-pn-realaudio-plugin\"></embed></object>"
            ,'mov'  => "<object classid=\"clsid:02BF25D5-8C17-4B23-BC80-D3488ABDDC6B\"  width=\"%1\$s\" height=\"%2\$s\" codebase=\"http://www.apple.com/qtactivex/qtplugin.cab\"><param name=\"src\" value=\"%3\$s\" /><param name=\"href\" value=\"%3\$s\" /><param name=\"controller\" value=\"true\" /><param name=\"pluginspage\" value=\"http://www.apple.com/quicktime/download/\" /><param name=\"autoplay\" value=\"true\" /><param name=\"bgcolor\" value=\"000000\" /><embed src=\"%3\$s\" width=\"%1\$s\" height=\"%2\$s\" bgcolor=\"000000\" autoplay=\"true\" controller=\"true\" src=\"%3\$s\" type=\"video/quicktime\" pluginspage=\"http://www.apple.com/quicktime/download/\"></embed></object>"
            ,'mpg'  => "<object id=\"winplayer\" classid=\"clsid:6BF52A52-394A-11d3-B153-00C04F79FAA6\" width=\"%1\$s\" height=\"%2\$s\" type=\"application/x-oleobject\"><param name=\"url\" value=\"%3\$s\" /><param name=\"autostart\" value=\"true\" /><param name=\"uiMode\" value=\"full\" /><embed src=\"%3\$s\" width=\"%1\$s\" height=\"%2\$s\" autostart=\"true\" uiMode=\"full\" type=\"application/x-mplayer2\" pluginspage=\"http://www.microsoft.com/windows/mediaplayer/\"></embed></object>"
            ,'swf'  => "<object data=\"%3\$s\" type=\"application/x-shockwave-flash\" width=\"%1\$s\" height=\"%2\$s\" wmode=\"transparent\"><param name=\"movie\" value=\"%3\$s\" /><param name=\"quality\" value=\"high\" /><param name=\"bgcolor\" value=\"#000000\" /><param name=\"wmode\" value=\"transparent\" /></object>"
            ,'flv'  => "<object data=\"%3\$s\" type=\"application/x-shockwave-flash\" width=\"%1\$s\" height=\"%2\$s\" wmode=\"transparent\"><param name=\"movie\" value=\"".$flvplayer."?file=%3\$s\" /><param name=\"quality\" value=\"high\" /><param name=\"bgcolor\" value=\"#000000\" /><param name=\"wmode\" value=\"transparent\" /></object>"
            );

 if($vid != '') {
  $site_url = '';
  $php_url  = '';
  if (function_exists('get_settings')) {
    $site_url = get_settings('siteurl').'/';
    $php_url = $site_url.$plugin_dir;
  } else {
    $php_url = dirname($_SERVER['REQUEST_URI'])."/";
    if (!strstr($php_url,'http://')) {$php_url = 'http://'.$_SERVER['SERVER_NAME'].$php_url;}
    $site_url = substr($php_url,0,strpos($php_url,'wp-content/'));
  }
  $flvplayer = $php_url.$flvplayer;

  // Get Video Data
  $video_dir  = '';
  if (defined('ABSPATH')) {
    $video_dir = ABSPATH.$upload_dir;
  } else {
    $video_dir = realpath('./../../../'.$upload_dir)."/";
  }
  $video_data = $video_dir.$video_data;
  if(file_exists($video_data)) {$a_vids = unserialize(file_get_contents($video_data));}

  // Check for not deleted
  if(is_array($a_vids) && array_key_exists($vid,$a_vids)) {
   // Check file or url source
   $src = "";
   if(!empty($a_vids[$vid]['lynkvp_url'])) {
    $src = 'http://'.$a_vids[$vid]['lynkvp_url'];
   } elseif(file_exists($video_dir.$a_vids[$vid]['lynkvp_id'].'.'.$a_vids[$vid]['lynkvp_type'])) {
    $src = $site_url.$upload_dir.$a_vids[$vid]['lynkvp_id'].'.'.$a_vids[$vid]['lynkvp_type'];
   }
   $width   = $video_sizes[$a_vids[$vid]['lynkvp_size']]['width'];
   $height  = $video_sizes[$a_vids[$vid]['lynkvp_size']]['height'];
   $caption = stripslashes($a_vids[$vid]['lynkvp_caption']);

   if ($src != "") {
    switch($a_vids[$vid]['lynkvp_type']) {
    case('rm'):
     $movie_type = 'real';
     break;
    case('mov'):
     $movie_type = 'mov';
     $height += 16;
     break;
    case('3gp'):
     $movie_type = 'mov';
     $height += 16;
     break;
    case('mp4'):
     $movie_type = 'mov';
     $height += 16;
     break;
    case('swf'):
     $movie_type = 'swf';
     break;
    case('flv'):
     $movie_type = 'flv';
     $src = $flvplayer."?file=".$src;
     break;
    default:
     $movie_type = 'mpg';
     $height += 16;
     break;
    }

    if ($cap_flg) {
     $out = sprintf($video_tmpl[$movie_type]."<br />%4\$s",$width,$height,$src,$caption);
    } else {
     $out = sprintf($video_tmpl[$movie_type],$width,$height,$src);
    }

   } else {
    $out = $lynk_err_note;
   }
  }// if key exists
  unset($a_vids);

 } else {
  $out = $lynk_err_note;
 }

 unset($video_sizes);
 unset($video_tmpl);

 return $out;
}
?>

==> videopop_plus-0.6.9.zip: videopop_plus/videopop_link.php <==
<?php
/*
VideoPop+ Plugin - Get Video Object
Version: 0.6.1

 Released under the GPL license
  http://www.gnu.org/copyleft/gpl.html
*/

function getVideoPopObject($vid='', $cap_flg=true, $flvplayer='flvplayer.swf', $lynk_err_note='Sorry, video not available.', $video_sizes='') {
 $upload_dir    = 'wp-content/videopop/';
 $plugin_dir    = 'wp-content/plugins/videopop_plus/';
 $video_data    = 'videopopdata.txt';

 if (!is_array($video_sizes)) {
  $video_sizes = array(
    160 => array('width' => 160, 'height' => 120, 'note' => '')
   ,320 => array('width' => 320, 'height' => 240, 'note' => '')
   ,640 => array('width' => 640, 'height' => 480, 'note' => '')
   ,719 => array('width' => 720, 'height' => 252, 'note' => '')
   ,450 => array('width' => 450, 'height' => 120, 'note' => ' [16:9 - 1.78:1]')
   ,480 => array('width' => 480, 'height' => 260, 'note' => '')
   ,720 => array('width' => 720, 'height' => 405, 'note' => ' [16:9 - 1.78:1]')
   ,721 => array('width' => 720, 'height' => 390, 'note' => ' [16:9 - 1.85:1]')
  );
 }

 $video_tmpl  = array(
             'real' => "<object id=\"realplayer\" classid=\"clsid:cfcdaa03-8be4-11cf-b84b-0020afbbccfa\" width=\"%1\$s\" height=\"%2\$s\"><param name=\"src\" value=\"%3\$s\" /><param name=\"autostart\" value=\"true\" /><param name=\"controls\" value=\"imagewindow,controlpanel\" /><embed src=\"%3\$s\" width=\"%1\$s\" height=\"%2\$s\" autostart=\"true\" controls=\"imagewindow,controlpanel\" type=\"audio/x-pn-realaudio-plugin\"></embed></object>"
            ,'mov'  => "<object classid=\"clsid:02BF25D5-8C17-4B23-BC80-D3488ABDDC6B\"  width=\"%1\$s\" height=\"%2\$s\" codebase=\"http://www.apple.com/qtactivex/qtplugin.cab\"><param name=\"src\" value=\"%3\$s\" /><param name=\"href\" value=\"%3\$s\" /><param name=\"controller\" value=\"true\" /><param name=\"pluginspage\" value=\"http://www.apple.com/quicktime/download/\" /><param name=\"autoplay\" value=\"true\" /><param name=\"bgcolor\" value=\"000000\" /><embed src=\"%3\$s\" width=\"%1\$s\" height=\"%2\$s\" bgcolor=\"000000\" autoplay=\"true\" controller=\"true\" src=\"%3\$s\" type=\"video/quicktime\" pluginspage=\"http://www.apple.com/quicktime/download/\"></embed></object>"
            ,'mpg'  => "<object id=\"winplayer\" classid=\"clsid:6BF52A52-394A-11d3-B153-00C04F79FAA6\" width=\"%1\$s\" height=\"%2\$s\" type=\"application/x-oleobject\"><param name=\"url\" value=\"%3\$s\" /><param name=\"autostart\" value=\"true\" /><param name=\"uiMode\" value=\"full\" /><embed src=\"%3\$s\" width=\"%1\$s\" height=\"%2\$s\" autostart=\"true\" uiMode=\"full\" type=\"application/x-mplayer2\" pluginspage=\"http://www.microsoft.com/windows/mediaplayer/\"></embed></object>"
            ,'swf'  => "<object data=\"%3\$s\" type=\"application/x-shockwave-flash\" width=\"%1\$s\" height=\"%2\$s\" wmode=\"transparent\"><param name=\"movie\" value=\"%3\$s\" /><param name=\"quality\" value=\"high\" /><param name=\"bgcolor\" value=\"#000000\" /><param name=\"wmode\" value=\"transparent\" /></object>"
            );

 if($vid != '') {
  $site_url = '';
  $php_url  = '';
  if (function_exists('get_settings')) {
    $site_url = get_settings('siteurl').'/';
    $php_url = $site_url.$plugin_dir;
  } else {
    $php_url = dirname($_SERVER['REQUEST_URI'])."/";
    if (!strstr($php_url,'http://')) {$php_url = 'http://'.$_SERVER['SERVER_NAME'].$php_url;}
    $site_url = substr($php_url,0,strpos($php_url,'wp-content/'));
  }
  $flvplayer = $php_url.$flvplayer;

  // Get Video Data
  $video_dir  = '';
  if (defined('ABSPATH')) {
    $video_dir = ABSPATH.$upload_dir;
  } else {
    $video_dir = realpath('./../../../'.$upload_dir)."/";
  }
  $video_data = $video_dir.$video_data;
  if(file_exists($video_data)) {$a_vids = unserialize(file_get_contents($video_data));}

  // Check for not deleted
  if(is_array($a_vids) && array_key_exists($vid,$a_vids)) {
   // Check file or url source
   $src = "";
   if(!empty($a_vids[$vid]['lynkvp_url'])) {
    $src = 'http://'.$a_vids[$vid]['lynkvp_url'];
   } elseif(file_exists($video_dir.$a_vids[$vid]['lynkvp_id'].'.'.$a_vids[$vid]['lynkvp_type'])) {
    $src = $site_url.$upload_dir.$a_vids[$vid]['lynkvp_id'].'.'.$a_vids[$vid]['lynkvp_type'];
   }
   $width   = $video_sizes[$a_vids[$vid]['lynkvp_size']]['width'];
   $height  = $video_sizes[$a_vids[$vid]['lynkvp_size']]['height'];
   $caption = stripslashes($a_vids[$vid]['lynkvp_caption']);
   if(!empty($a_vids[$vid]['lynkvp_image'])) {
    $image   = 'http://'.$a_vids[$vid]['lynkvp_image'];
   } else {
    $image   = '';
   }

   if ($src != "") {
    switch($a_vids[$vid]['lynkvp_type']) {
    case('rm'):
     $movie_type = 'real';
     break;
    case('mov'):
     $movie_type = 'mov';
     $height += 16;
     break;
    case('3gp'):
     $movie_type = 'mov';
     $height += 16;
     break;
    case('mp4'):
     $movie_type = 'mov';
     $height += 16;
     break;
    case('flv'):
     $movie_type = 'flv';
     $src = $flvplayer."?file=".$src;
     if ($image != '') {$src .= "&amp;image=".$image;}
     $height += 22;
    case('swf'):
     $movie_type = 'swf';
     break;
    default:
     $movie_type = 'mpg';
     $height += 16;
     break;
    }

    if ($cap_flg) {
     $out = sprintf($video_tmpl[$movie_type]."<br />%4\$s",$width,$height,$src,$caption);
    } else {
     $out = sprintf($video_tmpl[$movie_type],$width,$height,$src);
    }

   } else {
    $out = $lynk_err_note;
   }
  }// if key exists
  unset($a_vids);

 } else {
  $out = $lynk_err_note;
 }

 unset($video_sizes);
 unset($video_tmpl);

 return $out;
}
?>
